@@ -275,14 +275,26 @@ class OpenIDConnectBase(object):
         if not request.scopes or 'openid' not in request.scopes:
             return {}
 
-        # prompt other than 'none' should be handled by the server code that uses oauthlib
-        if request.prompt == 'none' and not request.id_token_hint:
-            msg = "Prompt is set to none yet id_token_hint is missing."
-            raise InvalidRequestError(request=request, description=msg)
+        prompt = request.prompt if request.prompt else []
+        if hasattr(prompt, 'split'):
+            prompt = prompt.strip().split()
+        prompt = set(prompt)
+
+        if 'none' in prompt:
+
+            if len(prompt) > 1:
+                msg = "Prompt none is mutually exclusive with other values."
+                raise InvalidRequestError(request=request, description=msg)
+
+            # prompt other than 'none' should be handled by the server code that
+            # uses oauthlib
+            if not request.id_token_hint:
+                msg = "Prompt is set to none yet id_token_hint is missing."
+                raise InvalidRequestError(request=request, description=msg)
 
-        if request.prompt == 'none':
             if not self.request_validator.validate_silent_login(request):
                 raise LoginRequired(request=request)
+
             if not self.request_validator.validate_silent_authorization(request):
                 raise ConsentRequired(request=request)
 
@@ -293,12 +305,6 @@ class OpenIDConnectBase(object):
             msg = "Session user does not match client supplied user."
             raise LoginRequired(request=request, description=msg)
 
-        prompt = []
-        if request.prompt:
-            prompt = request.prompt
-            if hasattr(prompt, 'split'):
-                prompt = prompt.split()
-
         request_info = {
             'display': request.display,
             'prompt': prompt,
@@ -335,6 +341,7 @@ class OpenIDConnectBase(object):
 
         return {'nonce': request.nonce, 'claims': request.claims}
 
+
 class OpenIDConnectAuthCode(OpenIDConnectBase):
 
     def __init__(self, request_validator=None, **kwargs):
@@ -364,6 +371,8 @@ class OpenIDConnectHybrid(OpenIDConnectBase):
 
         self.proxy_target = AuthorizationCodeGrant(
             request_validator=request_validator, **kwargs)
+        # All hybrid response types should be fragment-encoded.
+        self.proxy_target.default_response_mode = "fragment"
         self.register_response_type('code id_token')
         self.register_response_type('code token')
         self.register_response_type('code id_token token')
